# runcitadel

A package for developing and running citadel simulations.

## Installation

```bash
$ pip install runcitadel
```

## Usage

`runcitadel` can be used to connect a local simulation to a citadel session to perform
interactive computation on graphs. For usage examples, see the examples notebook in /docs/.

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`runcitadel` was created by Miles van der Lely. It is licensed under the terms of the MIT license.

## Credits

`runcitadel` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).

Developed in the Visualisation Lab at the University of Amsterdam (UvA).
